import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import com.nokia.controlpanel 0.1
import org.ancelad.ImagesModel 1.0

Page {
    id: page

    property string selectedPath: ""
    signal selected(string path)

    orientationLock: PageOrientation.LockPortrait
    tools: ToolBarLayout {
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: pageStack.pop()
        }
        ToolIcon {
            id: doneButton
            iconId: "toolbar-done"
            onClicked: {
                pageStack.pop()
                page.selected(selectedPath)
            }
        }
    }
    onStatusChanged: {
        if (status == PageStatus.Activating) {
            imagesModel.processPath("/home/user/MyDocs/enlargedavatar")
            doneButton.enabled = false
        }
    }

    ImagesModel {
        id: imagesModel
    }

    DcpPageTitle {
        id: titleLabel
        text: "Выберите аватар для удаления"
        anchors.top: page.top
    }

    GridView {
        id: flickable
        clip: true
        anchors.top: titleLabel.bottom
        anchors.bottom: page.bottom
        anchors.left: page.left
        anchors.right: page.right
        cellWidth: page.width / 4
        cellHeight: cellWidth
        cacheBuffer: cellHeight * 2

        model: imagesModel

        delegate: Item {
            width: (page.width / 4) - 1
            height: width

            Image {
                id: image
                source: model.dir ? ((model.name == "..") ? "images/back.png" : "images/folder.png") : model.path
                height: model.dir ? 64 : parent.height
                width: height
                sourceSize.height: height
                anchors.centerIn: parent
                fillMode: Image.PreserveAspectCrop
                clip: true
                smooth: true
                cache: true
                asynchronous: true

                states: [
                    State {
                        name: 'loaded'; when: image.status == Image.Ready
                        PropertyChanges { target: image; opacity: 1; }
                    },
                    State {
                        name: 'loading'; when: image.status != Image.Ready
                        PropertyChanges { target: image; opacity: 0; }
                    }
                ]

                Behavior on opacity {
                    NumberAnimation {
                        duration: 500
                        easing.type: Easing.InOutQuad
                        property: "opacity"
                    }
                }
            }

            Rectangle {
                anchors.fill: parent
                color: "#FFFFFF"
                visible: model.path == page.selectedPath
                opacity: 0.5
            }

            Rectangle {
                id: rec
                color: "#80000000"
                height: 20
                width: parent.width
                anchors.bottom: parent.bottom
                opacity: mArea.pressed ? 1.0 : 0.6
            }

            Label {
                anchors.fill: rec
                anchors.margins: 3
                height: 26
                font.pixelSize: 14
                text: model.name
                wrapMode: Text.NoWrap
                elide: Text.ElideRight
                horizontalAlignment : Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
            }

            MouseArea {
                id: mArea
                anchors.fill: parent
                onClicked: {
                    if (model.dir) {
                        imagesModel.processPath(model.path)
                        flickable.positionViewAtBeginning()
                    }
                    else if (page.selectedPath == model.path) {
                        page.selectedPath = ""
                        doneButton.enabled = false
                    }
                    else {
                        page.selectedPath = model.path
                        doneButton.enabled = true
                    }
                }
            }
        }
    }

    ScrollDecorator {
        flickableItem: flickable
    }
}
