import com.nokia.meego 1.0
import QtQuick 1.1
import com.nokia.extras 1.1
import com.nokia.controlpanel 0.1
import org.ancelad.Ambiance 1.0
import org.ancelad.GConf 1.0

Page {
    id: mainPage
    orientationLock: PageOrientation.LockPortrait
    tools: ToolBarLayout {
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: Qt.quit()
        }
    }
	
	Component.onCompleted: {      
              roundAvatar.checked = gconf.get("/apps/ancelad/round_avatar", false)
    }
	
    Ambiance {
        id: ambiance
    }

    GConf {
        id: gconf
    }	

    function avatarSelected(path) {
        banner.notify("Done! Refresh your phone!")
        ambiance.shell("/usr/share/duicontrolpanel/avatarsettings/remove_avatar.sh", [path])
    }
	
    Flickable {
        id: flickable
        anchors.fill: parent
        flickableDirection: Flickable.VerticalFlick
        contentHeight: content.height	
		
	Column {
        id: content
        spacing: 20
        width: parent.width
		
        DcpPageTitle {
                id: titleLabel
                text: "Avatar Settings"
            }

	        Label {
            text: "Rounded avatars"
            anchors.right: parent.right
            horizontalAlignment: Text.AlignHRight
            wrapMode: Text.WordWrap
			font.pixelSize: 26
            }		
			
            MySwitch {
                id: roundAvatar
                anchors.right: parent.right
                onClicked: {
                       width: 64
                       height: 64
                    if (checked) {
					   gconf.set("/apps/ancelad/round_avatar", "true")
                       ambiance.shell("/usr/share/duicontrolpanel/avatarsettings/round_avatar.sh")
                       banner.notify("Done! Refresh your phone!")
                       }
                    else {
					   gconf.set("/apps/ancelad/round_avatar", "false")
                       ambiance.shell("/usr/share/duicontrolpanel/avatarsettings/round_avatar.sh")
                       banner.notify("Done! Refresh your phone!")
                    }
                   gconf.set("/apps/ancelad/round_avatar", checked)
                }
            }
			
         Label {
            text: "If disabled - avatars are squared"
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.rightMargin: 16
            horizontalAlignment: Text.AlignHLeft
            wrapMode: Text.WordWrap
			font.pixelSize: 20
            }
			
			Separator {
                title: ""
                color: "white"
				width: 500
            }
			
        Label {
            text: "Unplug your phone from PC and copy your avatars to MyDocs"
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.rightMargin: 16
            horizontalAlignment: Text.AlignHLeft
            wrapMode: Text.WordWrap
			font.pixelSize: 20
            }			
		
        Button {
            anchors.horizontalCenter: parent.horizontalCenter
            text: "Copy to MyDocs"
            onClicked: {
			    gconf.set("/apps/ancelad/enlargedavatar", "MyDocs")
			    ambiance.shell("/usr/share/duicontrolpanel/avatarsettings/avatar.sh")
				banner.notify("Done!")
                }
            }

        Label {
            text: "Connect your phone to PC in mass-storage mode and find folder 'enlargedavatar'. Cut the original photo to the contact size 480x480 (or more, just keep the ratio 1 to 1) and save as appropriate contact png, with the same name. This mean, if the avatar is called 'ba5ce478494397060095.png', then it must necessarily retain the title. Unplug your phone from PC and copy them back..."
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.rightMargin: 16
            horizontalAlignment: Text.AlignHLeft
            wrapMode: Text.WordWrap
			font.pixelSize: 20
            }				
		
		Button {
            anchors.horizontalCenter: parent.horizontalCenter
            text: "Copy them back"
            onClicked: {
			    gconf.set("/apps/ancelad/enlargedavatar", "/dev/null")
			    ambiance.shell("/usr/share/duicontrolpanel/avatarsettings/avatar.sh")
				banner.notify("Done!")
                }
        }
    
	    Label {
            text: "Refresh your phone! Now your avatars have good quality!"
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.rightMargin: 16
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
			font.pixelSize: 26
        }
		
	    Item { //spacing
                width: 1
                height: 16
            }

	    Label {
            text: "Remove bad avatars, if you want"
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.rightMargin: 16
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
			font.pixelSize: 26
		}
		
        Button {
            text: "Remove avatar"
			anchors.horizontalCenter: parent.horizontalCenter
            width: (parent.width / 2) - 8
            onClicked: {
				gconf.set("/apps/ancelad/enlargedavatar", "MyDocs")
				ambiance.shell("/usr/share/duicontrolpanel/avatarsettings/avatar.sh")
                pageStack.push(Qt.resolvedUrl("AvatarPage.qml"))
                pageStack.currentPage.selected.connect(mainPage.avatarSelected)
                }
        }
	    
		Item { //spacing
                width: 1
                height: 40
        }
	 
	    Button {
                anchors.horizontalCenter: parent.horizontalCenter
                text: "Refresh your phone"
                onClicked: {
                    ambiance.shell("/usr/share/duicontrolpanel/avatarsettings/refresh.sh") 
                }
        }
	    
		Item { //spacing
                width: 1
                height: 30
        }	
		
	    Label {
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.rightMargin: 16
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            text:
                "<a href=\"http://talk.maemo.org/showpost.php?p=1417646&postcount=1\">Based on this tutorial</a>"
            onLinkActivated: Qt.openUrlExternally(link)
		}
		
		Item { //spacing
                width: 1
                height: 30
        }	
            Label {
                text:"You can make a donate, if you like my work."
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.right: parent.right
                anchors.rightMargin: 16
                horizontalAlignment: Text.AlignHCenter
                width: parent.width
            }
			
        Row {
		    height: 60
		    anchors.horizontalCenter: parent.horizontalCenter
            spacing: 10
			
            Button {              
                text: "USD"
				width: 140
                onClicked: {
                Qt.openUrlExternally("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=JWTJVWF8TLCDA")
                }
            }
				
            Button {                
                text: "RUB"
				width: 140
                onClicked: {
                Qt.openUrlExternally("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=LNYWHR2NUCGHU")
                }
            }
				
            Button {          
                text: "EUR"
				width: 140
                onClicked: {
                Qt.openUrlExternally("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=E33PBZ79WTQJY")
                }
			}
		}	
	    Label {
            text: "Thank you!"
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.rightMargin: 16
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
			font.pixelSize: 30
		}
		
		Item { //spacing
                width: 1
                height: 30
        }
		
		ScrollDecorator {
             flickableItem: flickable
        }   	   
    }
}
}
